import React, { Component } from 'react';
import PropTypes from 'prop-types';
import TextareaAutosize from 'react-textarea-autosize';
import moment from 'moment';
import Icon from '../Icon';

export default class InputFilename extends Component {
  handleChange = e => {
    const { onChange } = this.props;

    // The `TextareaAutosize` has a `value` attribute
    // which is supposed to be set to its inner `TextArea`'s value
    // but is always undefined
    // So this is a workaround
    this.refs.input.value = e.target.value;

    onChange(e.target.value);
  };

  render() {
    const { path, type } = this.props;

    let placeholder = 'example.md';
    if (type === 'posts') {
      const date = moment().format('YYYY-MM-DD');
      placeholder = `${date}-your-title.md`;
    } else if (type === 'data files') {
      placeholder = 'your-filename.yml';
    }

    let tooltip = null;
    if (type !== 'data files') {
      tooltip = (
        <span className="tooltip">
          <Icon name="info-circle" />
          <span className="tooltip-text">
            If you leave <b>path</b> blank, it will be autogenerated from title.
          </span>
        </span>
      );
    }
    return (
      <div className="input-path">
        <label>Path {tooltip}</label>
        <TextareaAutosize
          key={path}
          onChange={this.handleChange}
          placeholder={placeholder}
          defaultValue={path}
          ref="input"
        />
      </div>
    );
  }
}

InputFilename.propTypes = {
  path: PropTypes.string.isRequired,
  type: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
};
